/*	aspect ratio of this image is 1.24
	you can use the following sizes:
	+w300 +h372
	+w450 +h558
	+w600 +h744
	+w900 +h1116
*/

/*******************************************************************

  modifications:

    - 03-27-2003:
        Christoph Hormann: added water
                           added radiosity
                           added some dummy shapes
                           changed scale
                           changed light
                           changed sky

 *******************************************************************/


/************************************* Flags ****************************************/
#declare showDome = 1;
#declare showWater = 1;
#declare showTestObjects = 1;
#declare showSky = 1;

#declare use_Rad=true;
#declare use_area_light=false;


/********************************* global_settings **********************************/

global_settings {
   max_trace_level 10
   assumed_gamma 1

   #if (use_Rad)
     radiosity {
       pretrace_start 0.08
       pretrace_end   0.02
       count 60

       nearest_count 5
       error_bound 1.0
       recursion_limit 1

       low_error_factor .5
       gray_threshold 0.0
       minimum_reuse 0.015
       brightness 0.6

       normal on
       media on
     }
   #end
}

#if (use_Rad)
  #default { finish { ambient 0 } }
#end

/************************************* Camera ***************************************/
camera {
    location <0, 3, -60>
    right x*image_width/image_height
    up y
    look_at <0, 6, 0>
    angle 24
}


/************************************* Lights ***************************************/
//light_source{<10, 5, -3>*100 color rgb 1.5}
//light_source{<-10, 0.5, 3>*100 color rgb 0.6}

light_source {
  <10, 6, -3>*10000
  color rgb <2.0, 1.6, 1.3>*0.8

  #if (use_area_light)
    area_light 200*x 200*y  3,3
    jitter orient circular
  #end
}

/*********************************** Test Objects ***********************************/
#if(showTestObjects)
	//background{color rgb<0.6, 0.7, 1>}
	sphere{<0, 1, 0>, 1 pigment{color rgb<1, 0, 0>}}

union {
  box { <-1, -2, -12>, <5, 0.7, 12> }
  box { <4, -2, -10>, <8, 7, 10> }
  rotate -4*y
  translate <4, 0, -26>

  texture {
    pigment { color rgb 0.7 }
    finish { ambient 0 diffuse 0.6 }
  }
}

union {
  box { <0, -2, -5>, <-8, 10, 5> }
  box { <0, -2, -4>, <-7, 12, 4> translate <0.6, 0, 6>}
  box { <0, -2, -4>, <-7, 15, 4> translate <-0.6, 0, -9>}
  translate <-6, 0, -20>

  texture {
    pigment { color rgb<0.7, 0.67, 0.6> }
    finish { ambient 0 diffuse 0.4 }
  }
}

#end


/*************************************** Dome ***************************************/
#if(showDome)
	#include "colors.inc"
	#include "glass_old.inc"
	#include "metals.inc"
	#include "Stpaul.inc"

	//object{StPauls scale 0.05 translate<-30, 80, 230>}
	object{StPauls scale 0.035 translate<-20, 60, 420>}
#end

/**************************************** Sky ***************************************/
#if(showSky)

sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.00 rgb <0.96,0.95,0.91>*0.9]
      [0.07 rgb <0.72,0.8,0.92>*0.9]
      [0.20 rgb <0.45,0.58,0.8>*0.85]
      [0.37 rgb <0.26,0.43,0.72>*0.56]
    }
  }
}

#end

/*************************************** Water **************************************/
#if(showWater)
  #include "water.inc"
/*
	plane {
		y, 0
		pigment{color rgb<0.3, 0.5, 0.7>}
		finish{ambient 0.1 phong 0.8 reflection 0.3}
		normal{bumps 0.4 bump_size 0.1}

		scale 0.04
	}    */


#end



